@@ -1,18 +1,13 @@
 import datetime
-import time
 
 from arc import Context, namespace
-from arc.ui import SelectionMenu
-from arc.formatters import Box
 from arc.color import effects, fg
 
 from .. import helpers
 from .. import utils
 from .. import decos
 from ..harvest_api import HarvestApi
-from ..live_text import LiveText
-from ..clock import clock
-
+from .. import ui
 
 timer = namespace("timer")
 
@@ -29,15 +24,12 @@ def create(ctx: Context):
     projects: list[helpers.Project] = ctx.projects
 
     project_idx, _ = utils.exist_or_exit(
-        SelectionMenu([project.name for project in projects]).run()
+        ui.menu([project.name for project in projects])
     )
     print()
 
     project = projects[project_idx]
-
-    task_idx, _ = utils.exist_or_exit(
-        SelectionMenu([task.name for task in project.tasks]).run()
-    )
+    task_idx, _ = utils.exist_or_exit(ui.menu([task.name for task in project.tasks]))
     print()
 
     task = project.tasks[task_idx]
@@ -69,52 +61,10 @@ def running(ctx: Context, big: bool, clock_only: bool, interval: int = 10):
     """
     api: HarvestApi = ctx.api
 
-    header = (
-        lambda string: fg.WHITE
-        + effects.UNDERLINE
-        + effects.BOLD
-        + string
-        + effects.CLEAR
-    )
-
     size = "big" if big else "small"
-    try:
-        with LiveText("") as text:
-            while True:
-                entry = api.get_running_timer()
-                if not entry:
-                    break
-
-                entry = helpers.TimeEntry(entry)
-                hours, minutes = utils.parse_time(entry.hours)
-
-                time_display = Box(
-                    f"{fg.rgb(255, 110, 192)}{clock(hours, minutes, size)}{effects.CLEAR}",
-                    justify="center",
-                    padding={"top": 2, "bottom": 2, "left": 4, "right": 4},
-                )
-
-                if clock_only:
-                    text.update(time_display)
-
-                else:
-                    info_display = Box(
-                        f"{header('Project')}: {entry.project['name']}\n"
-                        f"{header('Task')}: {entry.task['name']}\n"
-                        f"{header('Notes')}: {entry.notes}\n",
-                        padding={"top": 2, "bottom": 2, "left": 4, "right": 4},
-                    )
-
-                    text.update(
-                        f"{info_display}\n{time_display}\n"
-                        f"{header('Fetch Interval')}: {interval} seconds"
-                    )
-
-                time.sleep(interval)
-    except KeyboardInterrupt:
-        return
-
-    print("No Timer Running")
+    message = ui.running_ui(api, interval, size, clock_only)
+    if message is not None:
+        print(message)
 
 
 @timer.subcommand()
